package com.install4j.api.beaninfo;

/**
 * Entry in an enumeration defined by {@link EnumerationMapper}.
 * An enumeration map entry maps a verbose description to an arbitrary object.
 * For primitive enumerated values, an instance of the corresponding wrapper class can be used for the object property.
 */
public class EnumerationMapEntry {
    
    private String name;
    private Object object;

    /**
     * Construct a map entry.
     * @param name the name
     * @param object the object
     */
    public EnumerationMapEntry(String name, Object object) {
        this.name = name;
        this.object = object;
    }

    /**
     * Get the name of the map entry. This name is displayed in the install4j GUI.
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * Get the object that is mapped to the specified name.
     * @return the object
     */
    public Object getObject() {
        return object;
    }
}
