package com.install4j.api.screens;

import com.install4j.api.beans.AbstractBean;
import com.install4j.api.context.InstallerContext;
import com.install4j.api.context.ProgressInterface;

/**
 * Abstract base class for installer screens.
 * All methods that have a reasonable default answer are overridden in the class.
 * This class saves the installer context that is set by the framework and provides a getter for it.
 *
 * @author ej-technologies GmbH
 */
public abstract class AbstractInstallerScreen extends AbstractBean implements InstallerScreen {

    private InstallerContext context;

    public void setInstallerContext(InstallerContext context) {
        this.context = context;
    }

    public boolean isNextVisible() {
        return true;
    }

    public boolean isPreviousVisible() {
        return true;
    }

    public boolean isCancelVisible() {
        return true;
    }

    public boolean isHiddenForNext() {
        return false;
    }

    public boolean isHiddenForPrevious() {
        return false;
    }

    public void activated() {
    }

    public void deactivated() {
    }

    public boolean next() {
        return true;
    }

    public boolean previous() {
        return true;
    }

    public boolean cancel() {
        return true;
    }

    public void willActivate() {

    }

    public boolean isHidden() {
        return false;
    }

    public boolean handleUnattended() {
        return true;
    }

    public boolean handleConsole(Console console) {
        return true;
    }

    public ProgressInterface getProgressInterface(ProgressInterface defaultProgressInterface) {
        return defaultProgressInterface;
    }

    public boolean hasTitlePanel() {
        return true;
    }

    /**
     * Returns the <tt>InstallerContext</tt> that the framework has associated with
     * this custom screen in <tt>setInstallerContext</tt>.
     * @return the installer context.
     */
    public InstallerContext getInstallerContext() {
        return context;
    }

}
