package com.install4j.api.unix;

import java.io.File;
import java.io.IOException;

/**
 * Collection of static methods to access Unix-specific file operations and information.
 * @author ej-technologies GmbH
 */
public class UnixFileSystem {

    /**
     * Set the Unix file mode for a file. For specifying integer file modes, you can use octal numbers by prefixing
     * a "0".
     * @param intMode the Unix file mode
     * @param destFile the file for which the mode should be set
     * @return whether the operation was cucessful or not
     */
    public static boolean setMode(int intMode, File destFile) {
        return com.install4j.runtime.installer.platform.unix.UnixFileSystem.setMode(intMode, destFile);
    }

    /**
     * Set the Unix file mode for a file.
     * @param mode the Unix file mode as an octal string, e.g. "755".
     * @param destFile the file for which the mode should be set
     * @return whether the operation was successful or not
     */
    public static boolean setMode(String mode, File destFile) {
        return com.install4j.runtime.installer.platform.unix.UnixFileSystem.setMode(mode, destFile);
    }

    /**
     * Create a symbolic link on Unix. If the link exists it will be overwritten.
     * @param destFileName the file where the link should point to
     * @param linkFile the link that should be created
     * @return whether the operation was successful or not
     */
    public static boolean createLink(String destFileName, File linkFile) {
        try {
            return com.install4j.runtime.installer.platform.unix.UnixFileSystem.createLink(destFileName, linkFile);
        } catch (IOException e) {
            return false;
        }
    }

    /**
     * Set the owner of a file.
     * @param owner the owner spec. Either a user name like "user" or a user name followed by a colon and a group name, like "user:group".
     * @param file the file for which the owener should be set.
     * @return whether the operation was successful or not
     */
    public static boolean setOwner(String owner, File file) {
        return com.install4j.runtime.installer.platform.unix.UnixFileSystem.setOwner(owner, file);
    }

    /**
     * Get Unix-specific information about a file.
     * @param file the file for which the information is requested.
     * @return the <tt>FileInformation</tt> object with the Unix-specific information
     */
    public static FileInformation getFileInformation(File file) {
        return com.install4j.runtime.installer.platform.unix.UnixFileSystem.getFileInformation(file);
    }

    /**
     * Holds Unix-specific information about a file.
     */
    public interface FileInformation {
        /**
         * Get the Unix mode of a file. To convert this mode to a human-readable octal string, use
         * <tt>Integer.toOctalString</tt>.
         * @return the Unix mode
         */
        int getMode();

        /**
         * Get the owner of a file. Depending on the platform, this is either a user name like
         * "user" or a user name followed by a colon and a group name, like "user:group".
         * @return the owner of the file.
         */
        String getOwnerInfo();

        /**
         * Return whether the file is a link or not.
         * @return <tt>true or false</tt>.
         */
        boolean isLink();

        /**
         * If <tt>isLink</tt> returns <tt>true</tt>, this method returns the target file of the link.
         * @return the target file if the file is a link or <tt>null</tt> otherwise.
         * @see #isLink()
         */
        String getLinkTarget();
    }

}
