package com.install4j.api.windows;

import com.install4j.runtime.installer.platform.win32.FolderInfo;

/**
 * Enumeration class for the different special system folders in Microsoft Windows.

 * @author ej-technologies GmbH
 */
public class SpecialFolder {
    /**
     * Identifies the file system directory used to physically store file objects on the desktop.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\Desktop</tt>.
     */
    public static final SpecialFolder DESKTOP = new SpecialFolder(FolderInfo.FOLDER_DESKTOP);

    /**
     * Identifies the file system directory containing Start menu items.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\Start Menu</tt>.
     */
    public static final SpecialFolder STARTMENU = new SpecialFolder(FolderInfo.FOLDER_STARTMENU);

    /**
     * Identifies the file system directory that contains the user's program groups.
     * The groups are themselves file system directories.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\Start Menu\Programs</tt>.
     */
    public static final SpecialFolder PROGRAMS = new SpecialFolder(FolderInfo.FOLDER_PROGRAMS);

    /**
     * Identifies the file system directory that corresponds to the user's Startup program group.
     * The system starts these programs whenever any user logs onto Windows NT or starts Windows 95.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\Start Menu\Programs\Startup</tt>.
     */
    public static final SpecialFolder STARTUP = new SpecialFolder(FolderInfo.FOLDER_STARTUP);

    /**
     * Identifies the file system directory that contains Send To menu items.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\SendTo</tt>.
     */
    public static final SpecialFolder SENDTO = new SpecialFolder(FolderInfo.FOLDER_SENDTO);

    /**
     * Identifies a virtual folder containing fonts.
     * A typical path is <tt>C:\Windows\Fonts</tt>.
     */
    public static final SpecialFolder FONTS = new SpecialFolder(FolderInfo.FOLDER_FONTS);

    /**
     * Identifies the file system directory that serves as a common repository for application-specific data.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\Application Data</tt>.
     * To get the ProgramData directory on Vista, use this value with allUsers set to <tt>true</tt>.
     */
    public static final SpecialFolder APPDATA = new SpecialFolder(FolderInfo.FOLDER_APPDATA);

    /**
     * Identifies the file system directory used to physically store a user's common repository of documents.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\My Documents</tt>.
     */
    public static final SpecialFolder DOCS = new SpecialFolder(FolderInfo.FOLDER_DOCS);

    /**
     * Identifies the file system directory that serves as a common repository for document templates.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\Templates</tt>.
     */
    public static final SpecialFolder TEMPLATES = new SpecialFolder(FolderInfo.FOLDER_TEMPLATES);

    /**
     * Identifies the file system directory that serves as a common repository for the user's favorite items.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\Favorites</tt>.
     */
    public static final SpecialFolder FAVORITES = new SpecialFolder(FolderInfo.FOLDER_FAVORITES);

    /**
     * Identifies the file system directory that serves as a data repository for local applications.
     * A typical path is <tt>C:\Documents and Settings\<i>username</i>\Local Settings\Application Data</tt>.
     */
    public static final SpecialFolder LOCAL_APPDATA = new SpecialFolder(FolderInfo.FOLDER_LOCAL_APPDATA);

    private int intValue;

    private SpecialFolder(int intValue) {
        this.intValue = intValue;
    }

    int getIntValue() {
        return intValue;
    }


}
